package com.rv.im.friend;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

import com.ruiwenliu.wrapper.base.BaseBean;
import com.ruiwenliu.wrapper.base.BaseStatusActivity;
import com.ruiwenliu.wrapper.weight.TitleView;
import com.rv.im.ImSetting;
import com.rv.im.R;
import com.rv.im.bean.AddResultBean;
import com.rv.im.db.service.ChatMessageServiceImp;
import com.rv.im.db.service.FriendServiceImp;
import com.rv.im.db.table.ChatMessage;
import com.rv.im.listener.NoDoubleClickListener;
import com.rv.im.presenter.RealAddFriendPresenter;
import com.rv.im.xmpp.ListenerManager;
import com.rv.im.xmpp.listener.ChatMessageListener;
import com.rv.im.xmpp.listener.NewFriendListener;

public class RealAddFriendActivity extends BaseStatusActivity<RealAddFriendPresenter> implements NewFriendListener {

    private static final String KEY_USER_ID = "userid";
    private static final String KEY_ADD_TYPE = "addtype";
    private static final String KEY_USER_NAME = "username";

    private EditText edtAddApply;
    private EditText edtAddRemark;

    private String userId;
    private String userName;
    private int fromAddType;

    public static Intent getIntent(Context context, String userId, String userName, int fromAddType) {
        Intent intent = new Intent(context, RealAddFriendActivity.class);
        intent.putExtra(KEY_USER_ID, userId);
        intent.putExtra(KEY_ADD_TYPE, fromAddType);
        intent.putExtra(KEY_USER_NAME, userName);
        return intent;
    }

    @Override
    protected int setLayout() {
        return R.layout.activity_real_add_friend;
    }

    @Override
    protected void initView(Bundle savedInstanceState, TitleView titleView, Intent intent) {
        titleView.setTitle("申请添加朋友");
        titleView.setText(R.id.tv_title_right, "发送");
        ((TextView) titleView.findViewById(R.id.tv_title_right)).setTextColor(Color.WHITE);
        titleView.findViewById(R.id.tv_title_right).setBackgroundResource(R.drawable.bg_btn_green_pre);
        titleView.setChildClickListener(R.id.tv_title_right, new NoDoubleClickListener() {
            @Override
            public void onNoDoubleClick(View view) {
                mPresenter.addFriend(userId, fromAddType);
            }
        });
        ListenerManager.getInstance().addNewFriendListener(this);
        userId = intent.getStringExtra(KEY_USER_ID);
        fromAddType = intent.getIntExtra(KEY_ADD_TYPE, 6);
        userName = intent.getStringExtra(KEY_USER_NAME);
        edtAddApply = findViewById(R.id.edt_add_apply);
        edtAddRemark = findViewById(R.id.edt_add_remark);
        edtAddApply.setText((!TextUtils.isEmpty(ImSetting.getUserName())) ? "我是" + ImSetting.getUserName() : "你好");
        if (!TextUtils.isEmpty(userName))
            edtAddRemark.setText(userName);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        ListenerManager.getInstance().removeNewFriendListener(this);
    }

    private int isyanzheng;

    private String addhaoyouid;

    @Override
    public void onShowResult(int requestType, BaseBean result) {
        switch (requestType) {
            case 0:
                if (result != null) {
                    AddResultBean bean = (AddResultBean) result;
                    if (bean.resultCode == 1 && bean.getData() != null) {
                        if (bean.getData().getType() == 1 || bean.getData().getType() == 3) {
                            isyanzheng = 0;// 需要验证
                            // 需要验证就发送打招呼的消息，
                            ChatMessage message = mPresenter.doSayHello(edtAddApply.getText().toString().trim(), userName, userId);
                            addhaoyouid = message != null ? message.getPackId() : "";
                        } else if (bean.getData().getType() == 2 || bean.getData().getType() == 4) {// 已经是好友了
                            isyanzheng = 1;// 不需要验证
                            ChatMessage message = mPresenter.doSayAddFriend(userName, userId);
                            addhaoyouid = message != null ? message.getPackId() : "";
                        } else if (bean.getData().getType() == 5) {
                            showToast(getString(R.string.add_attention_failed));
                        }
                    }
                }
                break;
        }
    }

    // xmpp消息发送成功最终回调到这，
    // 在这里调整ui,
    // 还有存本地数据库，
    public void msgSendSuccess(ChatMessage message, String packet) {
        if (addhaoyouid != null && addhaoyouid.equals(packet)) {
            if (isyanzheng == 0) {// 需要验证
                showToast("打招呼成功，静候回音");
                FriendServiceImp.getInstance(this).addMessage(mPresenter.buildAddFriendMessage(userId, userName, message.getMessageType()));
                setResult(RESULT_OK);
                finish();

//                ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
            } else if (isyanzheng == 1) {
                showToast("好友添加成功");
                // 数据库中添加好友
                FriendServiceImp.getInstance(this).addMessage(mPresenter.buildAddFriendMessage(userId, userName, message.getMessageType()));
                ChatMessageServiceImp.getInstance(this).addMessage(message);
                setResult(RESULT_OK);
                finish();

//                FriendDao.getInstance().updateFriendContent(mLoginUserId, mUser.getUserId(), InternationalizationHelper.getString("JXMessageObject_BeFriendAndChat"), XmppMessage.TYPE_TEXT, TimeUtils.sk_time_current_time());
//                ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);

//                loadOthersInfoFromNet();
//                CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
            }
            // 已经是好友了，mFriend不能为空，
//            mFriend = FriendDao.getInstance().getFriend(mLoginUserId, mUserId);
        }
//        else if (addblackid != null && addblackid.equals(packet)) {
//            Toast.makeText(getApplicationContext(), getString(R.string.add_blacklist_succ), Toast.LENGTH_SHORT).show();
//            findViewById(R.id.look_bussic_cicle_rl).setVisibility(View.GONE);
//            mNextStepBtn.setText(InternationalizationHelper.getString("REMOVE"));
//            mNextStepBtn.setOnClickListener(new RemoveBlacklistListener());
//
//            // 更新当前持有的Friend对象，
//            mFriend.setStatus(Friend.STATUS_BLACKLIST);
//            FriendDao.getInstance().updateFriendStatus(message.getOwnerId(), message.getUserId(), mFriend.getStatus());
//            FriendHelper.addBlacklistExtraOperation(message.getOwnerId(), message.getUserId());
//
//            ChatMessage addBlackChatMessage = new ChatMessage();
//            addBlackChatMessage.setContent(InternationalizationHelper.getString("JXFriendObject_AddedBlackList") + " " + mUser.getNickName());
//            addBlackChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, addBlackChatMessage);
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(mUser.getUserId(), Friend.STATUS_18);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            Intent intent = new Intent(this, MainActivity.class);
//            startActivity(intent);
//            finish();
//        } else if (removeblack != null && removeblack.equals(packet)) {
//            Toast.makeText(getApplicationContext(), InternationalizationHelper.getString("REMOVE_BLACKLIST"), Toast.LENGTH_SHORT).show();
//            findViewById(R.id.look_bussic_cicle_rl).setVisibility(View.VISIBLE);
//            mNextStepBtn.setText(InternationalizationHelper.getString("JXUserInfoVC_SendMseeage"));
//            mNextStepBtn.setOnClickListener(new SendMsgListener());
//
//            // 更新当前持有的Friend对象，
//            if (mFriend != null) {
//                mFriend.setStatus(Friend.STATUS_FRIEND);
//            }
//            NewFriendDao.getInstance().ascensionNewFriend(message, Friend.STATUS_FRIEND);
//            FriendHelper.beAddFriendExtraOperation(message.getOwnerId(), message.getUserId());
//
//            ChatMessage removeChatMessage = new ChatMessage();
//            removeChatMessage.setContent(coreManager.getSelf().getNickName() + InternationalizationHelper.getString("REMOVE"));
//            removeChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, removeChatMessage);
//           /* FriendDao.getInstance().updateFriendContent(mLoginUserId, message.getUserId(),
//                    InternationalizationHelper.getString("JXMessageObject_BeFriendAndChat"), XmppMessage.TYPE_TEXT, TimeUtils.sk_time_current_time());*/
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(message.getUserId(), Friend.STATUS_24);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            loadOthersInfoFromNet();
//        } else if (deletehaoyou != null && deletehaoyou.equals(packet)) {
//            Toast.makeText(getApplicationContext(), InternationalizationHelper.getString("JXAlert_DeleteOK"), Toast.LENGTH_SHORT).show();
//
//            FriendHelper.removeAttentionOrFriend(mLoginUserId, message.getUserId());
//
//            ChatMessage deleteChatMessage = new ChatMessage();
//            deleteChatMessage.setContent(InternationalizationHelper.getString("JXAlert_DeleteFirend") + " " + mUser.getNickName());
//            deleteChatMessage.setTimeSend(TimeUtils.sk_time_current_time());
//            FriendDao.getInstance().updateLastChatMessage(mLoginUserId, Friend.ID_NEW_FRIEND_MESSAGE, deleteChatMessage);
//
//            NewFriendDao.getInstance().createOrUpdateNewFriend(message);
//            NewFriendDao.getInstance().changeNewFriendState(mUser.getUserId(), Friend.STATUS_16);
//            ListenerManager.getInstance().notifyNewFriend(mLoginUserId, message, true);
//
//            CardcastUiUpdateUtil.broadcastUpdateUi(mContext);
//
//            Intent intent = new Intent(this, MainActivity.class);
//            startActivity(intent);
//            finish();
//        }
    }

    @Override
    public void onNewFriendSendStateChange(String toUserId, ChatMessage message, int messageState) {
        if (messageState == ChatMessageListener.MESSAGE_SEND_SUCCESS) {
            msgSendSuccess(message, message.getPackId());
        } else if (messageState == ChatMessageListener.MESSAGE_SEND_FAILED) {
//            msgSendFailed(message.getPacketId());
        }
    }

    @Override
    public boolean onNewFriend(ChatMessage message) {
        return false;
    }
}
